@@ -164,7 +164,7 @@ static const char _datB[]="\x01\x02"
 #define OFFSET 0x88                  /* Allow replacing sprite ranges with offsets */
 #define W(cnt) cnt & 0xFF, cnt >> 8  /* Construct word count */
 static const unsigned char _dat5[]={
-NDF_HEADER(0x04, 15),
+NDF_HEADER(0x04, 16),
 /*04*/ OFFSET,          OPTIONS(3), 0x30, 0x70, 0xF0,
 /*05*/ OFFSET,          OPTIONS(1), 0x30,
 /*06*/ OFFSET,          OPTIONS(2), 0x4A, 0x5A,
@@ -182,7 +182,7 @@ NDF_HEADER(0x04, 15),
 /*12*/ OFFSET,          OPTIONS(1), 0x08,
 /*13*/ OFFSET,          OPTIONS(1), 0x37,
 /*14*/ OFFSET,          OPTIONS(1), 0x24,
-/*15*/ OFFSET,          OPTIONS(1), 0xAE,
+/*15*/ OFFSET,          OPTIONS(1), 0xAF,
 /*16*/ OFFSET,          OPTIONS(1), 0x09,
 /*17*/ OFFSET,          OPTIONS(1), 0x10,
 00,
@@ -500,7 +500,7 @@ NDF_END
 #define REPEAT_UNTIL(data, length, ...) '*', data, length, __VA_ARGS__
 
 static const unsigned char _dat0[]={
-NDF_HEADER(0x0E, 0),
+NDF_HEADER(0x0E, 1),
 /*Maximum feature:*/ 0x11,
 // Feature 00:
 /*00*/ WORD | DATE, INVALID, BYTE, BYTE | DECIMAL, BYTE | DECIMAL, BYTE, BYTE, BYTE | DECIMAL,
@@ -711,7 +711,7 @@ END,
 // Feature 0F:
 /*00*/ INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID, INVALID,
 /*08*/ DWORD | QUOTED, WORD, WORD, BYTE, BYTE, BYTE, DWORD | DATE, DWORD | DATE,
-/*10*/ WORD | HEX, WORD | HEX, BYTE | DECIMAL, WORD, BYTE, WORD | HEX, BYTE, BYTE,
+/*10*/ WORD | HEX, WORD | HEX, BYTE | DECIMAL, WORD, BYTE, WORD | HEX, BYTE, BYTE, BYTE,
 END,
 
 // Feature 10:
@@ -779,10 +779,10 @@ NDF_END
 #define BYTE6x(var, max) VAR6x(var, 1, max)
 #define WORD6x(var, max) VAR6x(var, 2, max)
 #define DWORD6x(var, max) VAR6x(var, 4, max)
-#define LASTVAR80(var) (var == 0xFF ? 0xFF : var + 1), (var == 0xFF ? 0xF0 : 0x80)
+#define LASTVAR80(var) (var == 0xFF ? 0xFF : (unsigned char)(var + 1)), (var == 0xFF ? 0xF0 : 0x80)
 #define NOVAR80 LASTVAR80(0x7F)
 static const unsigned char _dat2v[]={
-NDF_HEADER(0x0D, 28),
+NDF_HEADER(0x0D, 30),
 /*Maximum feature:*/ 0x11,
 /*Maximum operator:*/ 0x16,
 // Global variables:
@@ -796,14 +796,14 @@ LASTVAR80(0xFF),
 /*Related:*/ 0x00,
 DWORD(0x25),
 VAR(0x40, 3), VAR(0x41, 3), DWORD(0x42), DWORD(0x43), VAR(0x45, 3), DWORD(0x46), DWORD(0x47),
-BYTE(0x48), DWORD(0x49), DWORD(0x4A), DWORD(0x4B), DWORD(0x4C),
+BYTE(0x48), DWORD(0x49), DWORD(0x4A), DWORD(0x4B), DWORD(0x4C), WORD(0x4D),
 WORD(0x5F),
 BYTE6x(0x60, 0x73), DWORD6x(0x61, 0xFF), DWORD6x(0x62, 0xFF),
 LASTVAR80(0xFF),
 // Feature 01:
 /*Related:*/ 0x01,
 VAR(0x40, 3), VAR(0x41, 3), VAR(0x42, 3), DWORD(0x43), VAR(0x45, 3), DWORD(0x46), DWORD(0x47),
-BYTE(0x48), DWORD(0x49), DWORD(0x4B), DWORD(0x4C),
+BYTE(0x48), DWORD(0x49), DWORD(0x4B), DWORD(0x4C), WORD(0x4D),
 WORD(0x5F),
 DWORD6x(0x61, 0xFF), DWORD6x(0x62, 0xFF),
 LASTVAR80(0xFF),
@@ -878,7 +878,7 @@ NOVAR80,
 /*Related:*/ 0x08,
 VAR(0x40, 3), WORD(0x41), DWORD(0x42), BYTE(0x43), BYTE(0x44), DWORD(0x45), DWORD(0x46), BYTE(0x47), BYTE(0x48),
 WORD(0x5F),
-WORD6x(0x60, 0xFF), BYTE6x(0x61, 0xFF), DWORD6x(0x62, 0xFF), WORD6x(0x63, 0xFF),
+DWORD6x(0x60, 0xFF), BYTE6x(0x61, 0xFF), DWORD6x(0x62, 0xFF), WORD6x(0x63, 0xFF),
 DWORD6x(0x64, 0xFF),
 NOVAR80,
 // Feature 10:
